pub struct InspectExecSession {
pub can_remove: Option<bool>,
pub container_id: Option<String>,
pub detach_keys: Option<String>,
pub exit_code: Option<i64>,
pub id: Option<String>,
pub open_stderr: Option<bool>,
pub open_stdin: Option<bool>,
pub open_stdout: Option<bool>,
pub pid: Option<i64>,
pub process_config: Option<InspectExecProcess>,
pub running: Option<bool>,
}Fields
can_remove: Option<bool>CanRemove is legacy and used purely for compatibility reasons. Will always be set to true, unless the exec session is running.
container_id: Option<String>ContainerID is the ID of the container this exec session is attached to.
detach_keys: Option<String>DetachKeys are the detach keys used by the exec session.
If set to “” the default keys are being used.
Will show “
exit_code: Option<i64>ExitCode is the exit code of the exec session. Will be set to 0 if the exec session has not yet exited.
id: Option<String>ID is the ID of the exec session.
open_stderr: Option<bool>OpenStderr is whether the container’s STDERR stream will be attached. Always set to true if the exec session created a TTY.
open_stdin: Option<bool>OpenStdin is whether the container’s STDIN stream will be attached to.
open_stdout: Option<bool>OpenStdout is whether the container’s STDOUT stream will be attached. Always set to true if the exec session created a TTY.
pid: Option<i64>Pid is the PID of the exec session’s process. Will be set to 0 if the exec session is not running.
process_config: Option<InspectExecProcess>running: Option<bool>Running is whether the exec session is running.