pub struct InspectMount {
pub destination: Option<String>,
pub driver: Option<String>,
pub mode: Option<String>,
pub name: Option<String>,
pub options: Option<Vec<String>>,
pub propagation: Option<String>,
pub rw: Option<bool>,
pub source: Option<String>,
pub type_: Option<String>,
}Expand description
InspectMount provides a record of a single mount in a container. It contains fields for both named and normal volumes. Only user-specified volumes will be included, and tmpfs volumes are not included even if the user specified them.
Fields
destination: Option<String>The destination directory for the volume. Specified as a path within the container, as it would be passed into the OCI runtime.
driver: Option<String>The driver used for the named volume. Empty for bind mounts.
mode: Option<String>Contains SELinux :z/:Z mount options. Unclear what, if anything, else goes in here.
name: Option<String>The name of the volume. Empty for bind mounts.
options: Option<Vec<String>>All remaining mount options. Additional data, not present in the original output.
propagation: Option<String>Mount propagation for the mount. Can be empty if not specified, but is always printed - no omitempty.
rw: Option<bool>Whether the volume is read-write
source: Option<String>The source directory for the volume.
type_: Option<String>Whether the mount is a volume or bind mount. Allowed values are “volume” and “bind”.