pub struct LibpodPingInfo {
pub api_version: String,
pub libpod_api_version: String,
pub libpod_buildah_version: String,
pub buildkit_version: Option<String>,
pub cache_control: String,
pub docker_experimental: bool,
pub pragma: String,
}Expand description
Data returned from /ping endpoint by libpod
Fields
api_version: StringMax compatibility API Version the server supports
libpod_api_version: StringMax Podman API Version the server supports. Available if service is backed by Podman, therefore may be used to determine if talking to Podman engine or another engine
libpod_buildah_version: StringDefault version of libpod image builder. Available if service is backed by Podman, therefore may be used to determine if talking to Podman engine or another engine
buildkit_version: Option<String>Default version of docker image builder
cache_control: StringAlways no-cache
docker_experimental: boolIf the server is running with experimental mode enabled, always true
pragma: StringAlways no-cache