Enum podman_api::opts::ImagePruneFilter
source · pub enum ImagePruneFilter {
Dangling(bool),
Until(String),
LabelKey(String),
LabelKeyVal(String, String),
NoLabelKey(String),
NoLabelKeyVal(String, String),
}Expand description
Used to filter removed images.
Variants
Dangling(bool)
When set to true, prune only unused and untagged images. When set to false, all unused images are pruned.
Until(String)
Prune images created before this timestamp. The
LabelKey(String)
Image with key label.
LabelKeyVal(String, String)
Image with key-value label.
NoLabelKey(String)
Image without key label.
NoLabelKeyVal(String, String)
Image without key-value label.