pub enum VolumeListFilter {
    Driver(String),
    LabelKey(String),
    LabelKeyVal(StringString),
    NoLabelKey(String),
    NoLabelKeyVal(StringString),
    Name(String),
    Opt(String),
    Until(String),
}
Used to filter listed volumes by one of the variants.

Variants



Driver(String)

Match a volume based on a driver.



LabelKey(String)

Volumes with a label.



LabelKeyVal(StringString)

Volumes with a key=value label.



NoLabelKey(String)

Volumes without a label.



NoLabelKeyVal(StringString)

Volumes without a key=value label.



Name(String)

Volume with name



Opt(String)

Volumes with storage driver opts



Until(String)

The can be Unix timestamps, date formatted timestamps, or Go duration strings (e.g. 10m, 1h30m) computed relative to the daemon machine’s time.