pub struct ContainerCheckpointOptsBuilder { /* private fields */ }Expand description
A builder struct for ContainerCheckpointOpts.
Implementations
Sourceimpl ContainerCheckpointOptsBuilder
impl ContainerCheckpointOptsBuilder
Sourcepub fn build(self) -> ContainerCheckpointOpts
pub fn build(self) -> ContainerCheckpointOpts
Finish building ContainerCheckpointOpts.
Sourceimpl ContainerCheckpointOptsBuilder
impl ContainerCheckpointOptsBuilder
Sourcepub fn file_locks(self, file_locks: bool) -> Self
pub fn file_locks(self, file_locks: bool) -> Self
Checkpoint a container with filelocks`
Sourcepub fn ignore_root_fs(self, ignore_root_fs: bool) -> Self
pub fn ignore_root_fs(self, ignore_root_fs: bool) -> Self
Do not include root file-system changes when exporting
Sourcepub fn ignore_volumes(self, ignore_volumes: bool) -> Self
pub fn ignore_volumes(self, ignore_volumes: bool) -> Self
Do not include associated volumes. can only be used with export
Sourcepub fn leave_running(self, leave_running: bool) -> Self
pub fn leave_running(self, leave_running: bool) -> Self
Leave the container running after writing checkpoint to disk
Sourcepub fn pre_checkpoint(self, pre_checkpoint: bool) -> Self
pub fn pre_checkpoint(self, pre_checkpoint: bool) -> Self
Dump the container’s memory information only, leaving the container running. only works on runc 1.0-rc or higher
Sourcepub fn print_stats(self, print_stats: bool) -> Self
pub fn print_stats(self, print_stats: bool) -> Self
Add checkpoint statistics to the returned CheckpointReport
Sourcepub fn tcp_established(self, tcp_established: bool) -> Self
pub fn tcp_established(self, tcp_established: bool) -> Self
Checkpoint a container with established TCP connections
Sourcepub fn with_previous(self, with_previous: bool) -> Self
pub fn with_previous(self, with_previous: bool) -> Self
Check out the container with previous criu image files in pre-dump. only works on runc 1.0-rc or higher