pub struct ManifestImageAddOptsBuilder { /* private fields */ }
A builder struct for ManifestImageAddOpts.

Implementations

Finish building ManifestImageAddOpts.

True when operating on a list to include all images.

Annotation to add to manifest list.

Overrides the architecture for the image.

Feature list for the image.

Optional list of images to add to manifest list.

Overrides the operating system for the image.

OS features for the image.

Overrides the operating system for the image.

Variant for the image.