Struct podman_api::opts::PodListOpts
source · pub struct PodListOpts { /* private fields */ }Expand description
Adjust the list of returned pods with this options.
Implementations
sourceimpl PodListOpts
impl PodListOpts
sourcepub fn builder() -> PodListOptsBuilder
pub fn builder() -> PodListOptsBuilder
Returns a new instance of a builder for PodListOpts.